# Commands

The general options that apply to all the commands listed below can be
found [under the `pip` page in this section](pip).

```{toctree}
:maxdepth: 1
:hidden:

pip
```

```{toctree}
:maxdepth: 1
:caption: Environment Management and Introspection

pip_install
pip_uninstall
pip_list
pip_show
pip_freeze
pip_check
```

```{toctree}
:maxdepth: 1
:caption: Handling Distribution Files

pip_download
pip_wheel
pip_hash
```

```{toctree}
:maxdepth: 1
:caption: Package Index information

pip_search
```

```{toctree}
:maxdepth: 1
:caption: Managing pip itself

pip_cache
pip_config
pip_debug
```
